.. _linux.ubuntu1804_mc:

##################
linux.ubuntu1804
##################

This Model Component provides initialization for an Ubuntu1804 VM.
It contains both Ubntu1804Server and Ubuntu1804Desktop.

**Model Component Dependencies:**
    * :ref:`linux.ubuntu_mc`

*****************
Available Objects
*****************

.. automodule:: linux.ubuntu1804
    :members:
    :undoc-members:
    :special-members:
    :private-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__,__module__
